import { DatabaseHelper } from "./DatabaseHelper";

/**
 * Friends helper
 * 
 * @author Pierre HUBERT
 */

const FRIENDS_TABLE = "amis";

export class FriendsHelper {

	/**
	 * Count the number of friendship requests a user
	 * received
	 * 
	 * @param userID Target user ID
	 */
	public static async CountRequests(userID: number) : Promise<number> {
		return await DatabaseHelper.Count({
			table: FRIENDS_TABLE,
			where: {
				ID_personne: userID,
				actif: 0
			}
		});
	}

	/**
	 * Count the number of friends of a specific user
	 * 
	 * @param userID Target user ID
	 */
	public static async CountForUser(userID: number) : Promise<number> {
		return await DatabaseHelper.Count({
			table: FRIENDS_TABLE,
			where: {
				ID_amis: userID,
				actif: 1
			}
		});
	}

	/**
	 * Check out whether two users are friend or not
	 * 
	 * @param userOne First user
	 * @param userTwo Second user
	 */
	public static async AreFriend(userOne: number, userTwo: number) : Promise<boolean> {
		return await DatabaseHelper.Count({
			table: FRIENDS_TABLE,
			where: {
				ID_personne: userOne,
				ID_amis: userTwo,
				actif: 1
			}
		}) > 0;
	}

	/**
	 * Check out whether friendship allows to create posts or not
	 * 
	 * @param userID User wishing to create a post
	 * @param targetID Target user ID
	 */
	public static async CanPostTexts(userID: number, targetID: number) : Promise<boolean> {
		const result = await DatabaseHelper.QueryRow({
			table: FRIENDS_TABLE,
			where: {
				ID_personne: targetID,
				ID_amis: userID,
				actif: 1
			},
			fields: ["autoriser_post_page"]
		});

		if(result == null)
			return false;
		
		return result["autoriser_post_page"] == 1;
	}
}